#include <avr/io.h>
#include <util/delay.h>
#include <avr/interrupt.h>
#include <avr/sleep.h>
#include "led.h"
#include "1wire.h"

#define DS18B20_CONVERT_T 0x44
#define DS18B20_READ_SCRATCHPAD 0xBE

float getTemperature();

struct scratchpad_struct {
	int16_t temperature;
	int16_t temperatureAlarm;
	uint8_t config;
	int8_t reserved[3];
	uint8_t crc;
};

int main(void) {
	PORTB |= _BV(PB2);
	GICR |= _BV(INT2);
	set_sleep_mode(SLEEP_MODE_PWR_DOWN);
	sleep_enable();
	ledInit();
	while(1){
		ledOff();
		sleep_cpu();
		float t = getTemperature();
		ledOn();
		ledDispNumber(t, "%g", 0);
		_delay_ms(3000);
	}
}

float getTemperature() {
	oneWireReset();
	oneWireSendByte(OW_SKIP_ROM);
	oneWireSendByte(DS18B20_CONVERT_T);
	_delay_ms(750);
	oneWireReset();
	oneWireSendByte(OW_SKIP_ROM);
	oneWireSendByte(DS18B20_READ_SCRATCHPAD);
	struct scratchpad_struct scratchpad;
	uint8_t * byte = (uint8_t *) &scratchpad;
	for (uint8_t i = 0; i < sizeof(scratchpad); i++)
	byte[i] = oneWireReceiveByte();
	return scratchpad.temperature / 16.0;
}

ISR(INT2_vect) {}
